@@ -1,8 +1,19 @@
+from abc import ABC
+from abc import abstractmethod
+from typing import TYPE_CHECKING
 from typing import Iterable
 from typing import NamedTuple
 from typing import Optional
 from typing import Tuple
 from typing import TypedDict
+from typing import Union
+
+
+if TYPE_CHECKING:
+    from explicit.messagebus import MessageBus
+    from explicit.unit_of_work import AbstractUnitOfWork
+    from rest_framework.request import Request
+    from rest_framework.viewsets import GenericViewSet
 
 
 class PermissionGroup(NamedTuple):
@@ -35,6 +46,22 @@ class TokenPermissionDict(TypedDict):
     """Временная метка после которой набор прав должен быть обновлён"""
 
 
+TUser = Union['AbstractBaseUser', 'OIDCUser']
+"""Тип "Пользователь системы"."""
+
+
+class TRule(ABC):
+    """Тип "Правило для проверки доступа"."""
+    @abstractmethod
+    def __call__(
+        self,
+        viewset: 'GenericViewSet',
+        request: 'Request',
+        user: TUser,
+    ) -> bool:
+        """Проверка доступа."""
+
+
 class TPermMapDict(TypedDict):
 
     """Структура сопоставления разрешений с действиями во ViewSet'е."""
